# Table of Contents

- [assigning-tags-to-fact-sheets-based-on-custom-calculated-field](<./assigning-tags-to-fact-sheets-based-on-custom-calculated-field.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Assigning Tags to Fact Sheets Based on Field Value Ranges](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges.md>)
  - [Overview](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Overview.md>)
  - [Prerequisites](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Prerequisites.md>)
  - [Step 1: Create a Custom Attribute for Energy Consumption on IT Component Fact Sheets](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Step-1-Create-a-Custom-Attribute-for-Energy-Consumption-on-IT-Component-Fact-Sheets.md>)
  - [Step 2: Create a Tag Group for T-Shirt Sizes](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Step-2-Create-a-Tag-Group-for-T-Shirt-Sizes.md>)
  - [Step 3: Create a Webhook for Energy Consumption Updates](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Step-3-Create-a-Webhook-for-Energy-Consumption-Updates.md>)
  - [Step 4: Create a Function to Assign Tags](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Step-4-Create-a-Function-to-Assign-Tags.md>)
  - [Step 5: Update the Webhook with the Function URL](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Step-5-Update-the-Webhook-with-the-Function-URL.md>)
  - [Summary](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Summary.md>)
  - [Was this page helpful?](<./Assigning-Tags-to-Fact-Sheets-Based-on-Field-Value-Ranges/Was-this-page-helpful.md>)
